pytomography.metadata.metadata — PyTomography 0.8.0 documentation

Skip to main content
`Ctrl`+`K`

# `pytomography.metadata.metadata`

## Module Contents

### Classes

`ObjectMeta` | Metadata for object space
`ImageMeta` | Metadata for image space
`PSFMeta` | Metadata for PSF correction. PSF blurring is implemented using Gaussian blurring with \(\sigma(r) = f(r,p)\) where \(r\) is the distance from the detector, :math`sigma` is the width of the Gaussian blurring at that location, and \(f(r,p)\) is the sigma_fit function which takes in additional parameters \(p\) called sigma_fit_params. (By default, sigma_fit is a linear curve). As such, \(\frac{1}{\sigma\sqrt{2\pi}}e^{-r^2/(2\sigma(r)^2)}\) is the point spread function. Blurring is implemented using convolutions with a specified kernel size.

class pytomography.metadata.metadata.ObjectMeta(dr, shape)

  Metadata for object space

  Parameters:

    - dr (list[float]) – List of 3 elements specifying voxel dimensions in cm.

    - shape (list[int]) – List of 3 elements [Lx, Ly, Lz] specifying the length of each dimension.

  compute_padded_shape()

    Computes the padded shape of an object required when rotating the object (to avoid anything getting cut off).

    Return type:

      list

  __repr__()

    Return repr(self).

class pytomography.metadata.metadata.ImageMeta(object_meta, angles, radii=None)

  Metadata for image space

  Parameters:

    - object_meta (ObjectMeta) – Corresponding object space metadata

    - angles (list) – Specifies the detector angles for all projections in image space

    - radii (list, optional) – Specifies the radial distance of the detector corresponding to each angle in angles; only required in certain cases (i.e. PSF correction). Defaults to None.

  compute_padded_shape()

    Computes the padded shape of an object required when rotating the object (to avoid anything getting cut off).

    Return type:

      list

  __repr__()

    Return repr(self).

class pytomography.metadata.metadata.PSFMeta(sigma_fit_params, sigma_fit=lambda r, a, b: ..., kernel_dimensions='2D', min_sigmas=3)

  Metadata for PSF correction. PSF blurring is implemented using Gaussian blurring with \(\sigma(r) = f(r,p)\) where \(r\) is the distance from the detector, :math`sigma` is the width of the Gaussian blurring at that location, and \(f(r,p)\) is the sigma_fit function which takes in additional parameters \(p\) called sigma_fit_params. (By default, sigma_fit is a linear curve). As such, \(\frac{1}{\sigma\sqrt{2\pi}}e^{-r^2/(2\sigma(r)^2)}\) is the point spread function. Blurring is implemented using convolutions with a specified kernel size.

  Parameters:

    - sigma_fit_params (float) – Parameters to the sigma fit function

    - sigma_fit (function) – Function used to model blurring as a function of radial distance. Defaults to a 2 parameter linear model.

    - kernel_dimensions (str) – If ‘1D’, blurring is done seperately in each axial plane (so only a 1 dimensional convolution is used). If ‘2D’, blurring is mixed between axial planes (so a 2D convolution is used). Defaults to ‘2D’.

    - min_sigmas (float, optional) – This is the number of sigmas to consider in PSF correction. PSF are modelled by Gaussian functions whose extension is infinite, so we need to crop the Gaussian when computing this operation numerically. Note that the blurring width is depth dependent, but the kernel size used for PSF blurring is constant. As such, this parameter is used to fix the kernel size such that all locations have at least `min_sigmas` of a kernel size.

  __repr__()

    Return repr(self).